@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Any, Callable, Optional, Union
 
-from sqlalchemy import Column, Table, and_, false, or_, true
+from sqlalchemy import Column, Table, and_, false, func, or_, true, extract
 from sqlalchemy.orm.relationships import RelationshipProperty
 from sqlalchemy.sql.elements import BooleanClauseList
 from typing_extensions import TypeGuard
@@ -135,3 +135,11 @@ class FilterIterator(Filter):
                 yield from self._fields(item)
             else:
                 yield item.field
+
+
+def day(column: Column):
+    return extract('DAY', column)
+
+
+def month(column: Column):
+    return extract('MONTH', column)
